@@ -2,7 +2,7 @@
 # the R software environment .
 # Copyright (C) 2012
 # University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu, 
+# Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,8 +19,6 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # or see http://www.r-project.org/Licenses/GPL-2
 
-".First.lib" <- function(lib, pkg) {
-    library.dynam("LatticeKrig", pkg, lib)
-     packageStartupMessage(" help(LKrig) gives an overview \n
-Copyright 2011, Licensed under GPL, www.gpl.org/licenses/gpl.html ")
+".on.Load" <- function(lib, pkg) {
+    packageStartupMessage("help(LKrig) gives an overview \n\nCopyright 2011, Licensed under GPL, www.gpl.org/licenses/gpl.html ")
 }
